@@ -21,16 +21,8 @@ export CODEC2DIR=$FREEDVGUIDIR/codec2
 export LPCNETDIR=$FREEDVGUIDIR/LPCNet
 
 # change this when working on combined codec2/freedv-gui changes
-CODEC2_BRANCH=v1.0.5
-LPCNET_BRANCH=v0.3
-
-# First build and install vanilla codec2 as we need -lcodec2 to build LPCNet
-cd $FREEDVGUIDIR
-if [ ! -d codec2 ]; then
-    git clone https://github.com/drowe67/codec2.git
-fi
-cd codec2 && git switch master && git pull && git checkout $CODEC2_BRANCH
-mkdir -p build_linux && cd build_linux && rm -Rf * && cmake .. && make
+CODEC2_BRANCH=master
+LPCNET_BRANCH=master
 
 # OK, build and test LPCNet
 cd $FREEDVGUIDIR
@@ -39,22 +31,28 @@ if [ ! -d LPCNet ]; then
 fi
 cd $LPCNETDIR && git switch master && git pull && git checkout $LPCNET_BRANCH
 mkdir  -p build_linux && cd build_linux && rm -Rf *
-cmake -DCODEC2_BUILD_DIR=$CODEC2DIR/build_linux ..
+cmake ..
 make
 # sanity check test
 cd src && sox ../../wav/wia.wav -t raw -r 16000 - | ./lpcnet_enc -s | ./lpcnet_dec -s > /dev/null
 
-# Re-build codec2 with LPCNet and test FreeDV 2020 support
-cd $CODEC2DIR/build_linux && rm -Rf *
-cmake -DLPCNET_BUILD_DIR=$LPCNETDIR/build_linux ..
-make VERBOSE=1
+# First build and install vanilla codec2 as we need -lcodec2 to build LPCNet
+cd $FREEDVGUIDIR
+if [ ! -d codec2 ]; then
+    git clone https://github.com/drowe67/codec2.git
+fi
+cd codec2 && git switch master && git pull && git checkout $CODEC2_BRANCH
+mkdir -p build_linux && cd build_linux && rm -Rf * && cmake -DLPCNET_BUILD_DIR=$LPCNETDIR/build_linux .. && make VERBOSE=1
 # sanity check test
 cd src
 export LD_LIBRARY_PATH=$LPCNETDIR/build_linux/src
 ./freedv_tx 2020 $LPCNETDIR/wav/wia.wav - | ./freedv_rx 2020 - /dev/null
 
 # Finally, build freedv-gui
-cd $FREEDVGUIDIR && git pull
+cd $FREEDVGUIDIR
+if [ -d .git ]; then
+     git pull
+fi
 mkdir  -p build_linux && cd build_linux && rm -Rf *
 if [[ "$FREEDV_VARIANT" == "pulseaudio" ]]; then
     PULSEAUDIO_PARAM="-DUSE_PULSEAUDIO=1"
