@@ -223,14 +223,12 @@ void FreeDVInterface::stop()
     rxMode_ = 0;
 }
 
-void FreeDVInterface::setRunTimeOptions(int clip, int bpf, int phaseEstBW, int phaseEstDPSK)
+void FreeDVInterface::setRunTimeOptions(bool clip, bool bpf)
 {
     for (auto& dv : dvObjects_)
     {
         freedv_set_clip(dv, clip);   // 700D/700E
         freedv_set_tx_bpf(dv, bpf);  // 700D/700E
-        freedv_set_phase_est_bandwidth_mode(dv, phaseEstBW); // 700D/2020
-        freedv_set_dpsk(dv, phaseEstDPSK);  // 700D/2020
     }
 }
 
@@ -495,7 +493,7 @@ int FreeDVInterface::getRxSpeechSampleRate() const
     return result;
 }
 
-void FreeDVInterface::setSquelch(int enable, float level)
+void FreeDVInterface::setSquelch(bool enable, float level)
 {
     int index = 0;
     
