@@ -72,6 +72,7 @@
 #include "modem_stats.h"
 
 #include "topFrame.h"
+#include "dlg_easy_setup.h"
 #include "dlg_ptt.h"
 #include "dlg_options.h"
 #include "plot.h"
@@ -98,6 +99,7 @@
 #define _DUMMY_DATA             1
 //#define _AUDIO_PASSTHROUGH    1
 #define _REFRESH_TIMER_PERIOD   (DT*1000)
+
 //#define _USE_ABOUT_DIALOG       1
 
 enum {
@@ -107,6 +109,7 @@ enum {
         ID_TIMER_SCATTER,
         ID_TIMER_SCALAR,
         ID_TIMER_PSKREPORTER,
+        ID_TIMER_UPD_FREQ,
      };
 
 #define EXCHANGE_DATA_IN    0
@@ -232,6 +235,7 @@ class MainApp : public wxApp
         wxString            m_callSign;
         unsigned int        m_textEncoding;
         bool                m_snrSlow;
+        unsigned int        m_statsResetTimeSec;
 
         // LPC Post Filter
         bool                m_codec2LPCPostFilterEnable;
@@ -284,7 +288,7 @@ class MainApp : public wxApp
         bool                m_psk_enable;
         wxString            m_psk_callsign;
         wxString            m_psk_grid_square;
-        int                 m_psk_freq;
+        uint64_t            m_psk_freq;
 
         PskReporter*            m_pskReporter;
         std::string         m_pskPendingCallsign;
@@ -310,10 +314,6 @@ class MainApp : public wxApp
         bool       m_FreeDV700txClip;
         bool       m_FreeDV700txBPF;
         bool       m_FreeDV700Combine;
-        bool       m_FreeDV700ManualUnSync;
-
-        bool       m_PhaseEstBW;
-        bool       m_PhaseEstDPSK;
 
         // Noise simulation
 
@@ -339,6 +339,9 @@ class MainApp : public wxApp
         bool       m_txRxThreadHighPriority;
 
         int        m_prevMode;
+        
+        bool       m_firstTimeUse;
+        bool       m_2020Allowed;
 
     protected:
 };
@@ -429,6 +432,7 @@ class MainFrame : public TopFrame
         
         // Not sure why we have the option to disable timers. TBD?
         wxTimer                 m_pskReporterTimer;
+        wxTimer                 m_updFreqStatusTimer; //[UP]
 #endif
 
     void destroy_fifos(void);
@@ -478,6 +482,8 @@ class MainFrame : public TopFrame
         void OnTop(wxCommandEvent& event);
         void OnExit( wxCommandEvent& event );
 
+        void OnToolsEasySetup( wxCommandEvent& event );
+        void OnToolsEasySetupUI( wxUpdateUIEvent& event );
         void OnToolsAudio( wxCommandEvent& event );
         void OnToolsAudioUI( wxUpdateUIEvent& event );
         void OnToolsComCfg( wxCommandEvent& event );
@@ -536,6 +542,7 @@ class MainFrame : public TopFrame
         std::shared_ptr<IAudioDevice> txInSoundDevice;
         std::shared_ptr<IAudioDevice> txOutSoundDevice;
         
+        unsigned int         m_timeSinceSyncLoss;
         bool        m_useMemory;
         wxTextCtrl* m_tc;
         int         m_zoom;
@@ -567,15 +574,16 @@ class MainFrame : public TopFrame
         int        vk_repeats, vk_repeat_counter;
         float      vk_rx_time;
         float      vk_rx_sync_time;
-
-        void       checkAvxSupport();
-        bool       isAvxPresent;
         
         int         getSoundCardIDFromName(wxString& name, bool input);
         bool        validateSoundCardSetup();
         
-    private:
         void loadConfiguration_();
+        void resetStats_();
+
+#if defined(FREEDV_MODE_2020)
+        void test2020Mode_();
+#endif // defined(FREEDV_MODE_2020)
 };
 
 //-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=--=-=-=-=
