@@ -5,6 +5,7 @@
 */
 
 #include "main.h"
+#include "lpcnet_freedv.h"
 
 extern int g_mode;
 extern bool  g_modal;
@@ -42,6 +43,23 @@ void MainFrame::OnExitClick(wxCommandEvent& event)
     OnExit(event);
 }
 
+//-------------------------------------------------------------------------
+// OnToolsEasySetup()
+//-------------------------------------------------------------------------
+void MainFrame::OnToolsEasySetup(wxCommandEvent& event)
+{
+    EasySetupDialog* dlg = new EasySetupDialog(this);
+    dlg->ShowModal();
+}
+
+//-------------------------------------------------------------------------
+// OnToolsEasySetupUI()
+//-------------------------------------------------------------------------
+void MainFrame::OnToolsEasySetupUI(wxUpdateUIEvent& event)
+{
+    event.Enable(!m_RxRunning);
+}
+
 //-------------------------------------------------------------------------
 // OnToolsAudio()
 //-------------------------------------------------------------------------
@@ -282,7 +300,7 @@ void MainFrame::OnCmdSliderScroll(wxScrollEvent& event)
 {
     char sqsnr[15];
     g_SquelchLevel = (float)m_sliderSQ->GetValue()/2.0 - 5.0;
-    sprintf(sqsnr, "%4.1f dB", g_SquelchLevel); // 0.5 dB steps
+    snprintf(sqsnr, 15, "%4.1f dB", g_SquelchLevel); // 0.5 dB steps
     wxString sqsnr_string(sqsnr);
     m_textSQ->SetLabel(sqsnr_string);
 
@@ -296,7 +314,7 @@ void MainFrame::OnChangeTxLevel( wxScrollEvent& event )
 {
     char fmt[15];
     g_txLevel = m_sliderTxLevel->GetValue();
-    sprintf(fmt, "%0.1f dB", (double)(g_txLevel)/10.0);
+    snprintf(fmt, 15, "%0.1f dB", (double)(g_txLevel)/10.0);
     wxString fmtString(fmt);
     m_txtTxLevelNum->SetLabel(fmtString);
     
@@ -419,7 +437,7 @@ void MainFrame::togglePTT(void) {
         m_textSync->Enable();
         m_textCurrentDecodeMode->Enable();
         
-        // Reenable On/Off button.
+        // Re-enable On/Off button.
         m_togBtnOnOff->Enable(true);
     }
     else
@@ -520,8 +538,7 @@ void MainFrame::OnReSync(wxCommandEvent& event)
     }
 }
 
-
-void MainFrame::OnBerReset(wxCommandEvent& event)
+void MainFrame::resetStats_()
 {
     if (m_RxRunning)  {
         freedvInterface.resetBitStats();
@@ -536,6 +553,11 @@ void MainFrame::OnBerReset(wxCommandEvent& event)
     }
 }
 
+void MainFrame::OnBerReset(wxCommandEvent& event)
+{
+    resetStats_();
+}
+
 void MainFrame::OnChangeReportFrequency( wxCommandEvent& event )
 {
     wxString freqStr = m_txtCtrlReportFrequency->GetValue();
