@@ -65,12 +65,19 @@ TopFrame::TopFrame(wxWindow* parent, wxWindowID id, const wxString& title, const
     m_menubarMain->Append(file, _("&File"));
 
     tools = new wxMenu();
+    wxMenuItem* m_menuItemEasySetup;
+    m_menuItemEasySetup = new wxMenuItem(tools, wxID_ANY, wxString(_("&Easy Setup...")) , _("Simplified setup of FreeDV"), wxITEM_NORMAL);
+    tools->Append(m_menuItemEasySetup);
+    
+    wxMenuItem* toolsSeparator1 = new wxMenuItem(tools, wxID_SEPARATOR);
+    tools->Append(toolsSeparator1);
+    
     wxMenuItem* m_menuItemAudio;
     m_menuItemAudio = new wxMenuItem(tools, wxID_ANY, wxString(_("&Audio Config...")) , _("Configures sound cards for FreeDV"), wxITEM_NORMAL);
     tools->Append(m_menuItemAudio);
 
     wxMenuItem* m_menuItemRigCtrlCfg;
-    m_menuItemRigCtrlCfg = new wxMenuItem(tools, wxID_ANY, wxString(_("&PTT Config...")) , _("Configures FreeDV integration with radio"), wxITEM_NORMAL);
+    m_menuItemRigCtrlCfg = new wxMenuItem(tools, wxID_ANY, wxString(_("P&TT Config...")) , _("Configures FreeDV integration with radio"), wxITEM_NORMAL);
     tools->Append(m_menuItemRigCtrlCfg);
 
     wxMenuItem* m_menuItemOptions;
@@ -80,6 +87,9 @@ TopFrame::TopFrame(wxWindow* parent, wxWindowID id, const wxString& title, const
     wxMenuItem* m_menuItemFilter;
     m_menuItemFilter = new wxMenuItem(tools, wxID_ANY, wxString(_("&Filter...")) , _("Configures audio filtering"), wxITEM_NORMAL);
     tools->Append(m_menuItemFilter);
+    
+    wxMenuItem* toolsSeparator2 = new wxMenuItem(tools, wxID_SEPARATOR);
+    tools->Append(toolsSeparator2);
 
     m_menuItemPlayFileToMicIn = new wxMenuItem(tools, wxID_ANY, wxString(_("Start Play File - &Mic In...")) , _("Pipes microphone sound input from file"), wxITEM_NORMAL);
     g_playFileToMicInEventId = m_menuItemPlayFileToMicIn->GetId();
@@ -140,8 +150,8 @@ TopFrame::TopFrame(wxWindow* parent, wxWindowID id, const wxString& title, const
     //------------------------------
     // Box for S/N ratio (Numeric)
     //------------------------------
-    m_textSNR = new wxStaticText(snrBox, wxID_ANY, wxT(" 0.0"), wxDefaultPosition, wxDefaultSize, wxALIGN_CENTRE);
-    m_textSNR->SetMinSize(wxSize(40,-1));
+    m_textSNR = new wxStaticText(snrBox, wxID_ANY, wxT(" 0.0 dB"), wxDefaultPosition, wxDefaultSize, wxALIGN_CENTRE);
+    m_textSNR->SetMinSize(wxSize(70,-1));
     snrSizer->Add(m_textSNR, 0, wxALIGN_CENTER_HORIZONTAL, 1);
 
     //------------------------------
@@ -273,7 +283,7 @@ TopFrame::TopFrame(wxWindow* parent, wxWindowID id, const wxString& title, const
     //=====================================================
     // Right side
     //=====================================================
-    wxSizer* rightSizer = new wxWrapSizer(wxVERTICAL);
+    rightSizer = new wxWrapSizer(wxVERTICAL);
 
     //=====================================================
     // Squelch Slider Control
@@ -323,32 +333,49 @@ TopFrame::TopFrame(wxWindow* parent, wxWindowID id, const wxString& title, const
     //------------------------------
     // Mode box
     //------------------------------
-    wxStaticBoxSizer* sbSizer_mode;
-    wxStaticBox* modeBox = new wxStaticBox(panel, wxID_ANY, _("&Mode"));
+    modeBox = new wxStaticBox(panel, wxID_ANY, _("&Mode"));
     sbSizer_mode = new wxStaticBoxSizer(modeBox, wxVERTICAL);
 
-    m_rb700c = new wxRadioButton( modeBox, wxID_ANY, wxT("700C"), wxDefaultPosition, wxDefaultSize,  wxRB_GROUP);
-    sbSizer_mode->Add(m_rb700c, 0, wxALIGN_LEFT|wxALL, 1);
-    m_rb700d = new wxRadioButton( modeBox, wxID_ANY, wxT("700D"), wxDefaultPosition, wxDefaultSize,  0);
+    m_rb700d = new wxRadioButton( modeBox, wxID_ANY, wxT("700D"), wxDefaultPosition, wxDefaultSize,  wxRB_GROUP);
     sbSizer_mode->Add(m_rb700d, 0, wxALIGN_LEFT|wxALL, 1);
     m_rb700e = new wxRadioButton( modeBox, wxID_ANY, wxT("700E"), wxDefaultPosition, wxDefaultSize,  0);
     sbSizer_mode->Add(m_rb700e, 0, wxALIGN_LEFT|wxALL, 1);
-    m_rb800xa = new wxRadioButton( modeBox, wxID_ANY, wxT("800XA"), wxDefaultPosition, wxDefaultSize, 0);
-    sbSizer_mode->Add(m_rb800xa, 0, wxALIGN_LEFT|wxALL, 1);
     m_rb1600 = new wxRadioButton( modeBox, wxID_ANY, wxT("1600"), wxDefaultPosition, wxDefaultSize, 0);
     sbSizer_mode->Add(m_rb1600, 0, wxALIGN_LEFT|wxALL, 1);
-    m_rb2400b = new wxRadioButton( modeBox, wxID_ANY, wxT("2400B"), wxDefaultPosition, wxDefaultSize, 0);
-    sbSizer_mode->Add(m_rb2400b, 0, wxALIGN_LEFT|wxALL, 1);
-    m_rb2020 = new wxRadioButton( modeBox, wxID_ANY, wxT("2020"), wxDefaultPosition, wxDefaultSize,  0);
-    sbSizer_mode->Add(m_rb2020, 0, wxALIGN_LEFT|wxALL, 1);
+    m_hiddenMode1 = new wxRadioButton( modeBox, wxID_ANY, wxT("hidden2"), wxDefaultPosition, wxDefaultSize, 0);
+    sbSizer_mode->Add(m_hiddenMode1, 0, wxALIGN_LEFT|wxALL, 1);
+    m_hiddenMode1->Show(false);
+    
+    m_collpane = new wxCollapsiblePane(modeBox, ID_MODE_COLLAPSE, "Others:");
+    sbSizer_mode->Add(m_collpane, 0, wxGROW|wxALL, 5);
+    
+    wxWindow *otherModeWin = m_collpane->GetPane();
+    wxSizer *otherModeSizer = new wxBoxSizer(wxVERTICAL);
+    
+    m_rb700c = new wxRadioButton( otherModeWin, wxID_ANY, wxT("700C"), wxDefaultPosition, wxDefaultSize,  0);
+    otherModeSizer->Add(m_rb700c, 1, wxALIGN_LEFT|wxALL|wxGROW, 1);
+    m_rb800xa = new wxRadioButton( otherModeWin, wxID_ANY, wxT("800XA"), wxDefaultPosition, wxDefaultSize, 0);
+    otherModeSizer->Add(m_rb800xa, 1, wxALIGN_LEFT|wxALL|wxGROW, 1);
+    m_rb2400b = new wxRadioButton( otherModeWin, wxID_ANY, wxT("2400B"), wxDefaultPosition, wxDefaultSize, 0);
+    otherModeSizer->Add(m_rb2400b, 1, wxALIGN_LEFT|wxALL|wxGROW, 1);
+    m_rb2020 = new wxRadioButton( otherModeWin, wxID_ANY, wxT("2020"), wxDefaultPosition, wxDefaultSize,  0);
+    otherModeSizer->Add(m_rb2020, 1, wxALIGN_LEFT|wxALL|wxGROW, 1);
 #if defined(FREEDV_MODE_2020B)
-    m_rb2020b = new wxRadioButton( modeBox, wxID_ANY, wxT("2020B"), wxDefaultPosition, wxDefaultSize,  0);
-    sbSizer_mode->Add(m_rb2020b, 0, wxALIGN_LEFT|wxALL, 1);
+    m_rb2020b = new wxRadioButton( otherModeWin, wxID_ANY, wxT("2020B"), wxDefaultPosition, wxDefaultSize,  0);
+    otherModeSizer->Add(m_rb2020b, 1, wxALIGN_LEFT|wxALL|wxGROW, 1);
 #endif // FREEDV_MODE_2020B
-    sbSizer_mode->SetMinSize(wxSize(100,-1));
-    m_rb1600->SetValue(true);
+    m_hiddenMode2 = new wxRadioButton( otherModeWin, wxID_ANY, wxT("hidden2"), wxDefaultPosition, wxDefaultSize, 0);
+    otherModeSizer->Add(m_hiddenMode2, 0, wxALIGN_LEFT|wxALL, 1);
+    m_hiddenMode2->Show(false);
 
-    rightSizer->Add(sbSizer_mode,0, wxALL|wxEXPAND, 3);
+    m_hiddenMode1->SetValue(true);
+    m_hiddenMode2->SetValue(true);
+
+    sbSizer_mode->SetMinSize(wxSize(100,-1));
+    otherModeWin->SetSizer(otherModeSizer);
+    otherModeSizer->SetSizeHints(otherModeWin);
+
+    rightSizer->Add(sbSizer_mode,0, wxALL|wxGROW, 3);
 
     //=====================================================
     // Control Toggles box
@@ -466,17 +493,17 @@ TopFrame::TopFrame(wxWindow* parent, wxWindowID id, const wxString& title, const
     //=====================================================
     // End of layout
     //=====================================================
-
+    
     //-------------------
     // Tab ordering for accessibility
     //-------------------
     m_auiNbookCtrl->MoveBeforeInTabOrder(m_BtnCallSignReset);
     m_sliderSQ->MoveBeforeInTabOrder(m_ckboxSQ);
-    m_rb700c->MoveBeforeInTabOrder(m_rb700d);
     m_rb700d->MoveBeforeInTabOrder(m_rb700e);
-    m_rb700e->MoveBeforeInTabOrder(m_rb800xa);
-    m_rb800xa->MoveBeforeInTabOrder(m_rb1600);
-    m_rb1600->MoveBeforeInTabOrder(m_rb2400b);
+    m_rb700e->MoveBeforeInTabOrder(m_rb1600);
+    
+    m_rb700c->MoveBeforeInTabOrder(m_rb800xa);
+    m_rb800xa->MoveBeforeInTabOrder(m_rb2400b);
     m_rb2400b->MoveBeforeInTabOrder(m_rb2020);
 #if defined(FREEDV_MODE_2020B)
     m_rb2020->MoveBeforeInTabOrder(m_rb2020b);
@@ -497,6 +524,8 @@ TopFrame::TopFrame(wxWindow* parent, wxWindowID id, const wxString& title, const
     this->Connect(m_menuItemExit->GetId(), wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler(TopFrame::OnExit));
     this->Connect(m_menuItemOnTop->GetId(), wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler(TopFrame::OnTop));
 
+    this->Connect(m_menuItemEasySetup->GetId(), wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler(TopFrame::OnToolsEasySetup));
+    this->Connect(m_menuItemEasySetup->GetId(), wxEVT_UPDATE_UI, wxUpdateUIEventHandler(TopFrame::OnToolsEasySetupUI));
     this->Connect(m_menuItemAudio->GetId(), wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler(TopFrame::OnToolsAudio));
     this->Connect(m_menuItemAudio->GetId(), wxEVT_UPDATE_UI, wxUpdateUIEventHandler(TopFrame::OnToolsAudioUI));
     this->Connect(m_menuItemFilter->GetId(), wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler(TopFrame::OnToolsFilter));
@@ -549,6 +578,8 @@ TopFrame::TopFrame(wxWindow* parent, wxWindowID id, const wxString& title, const
     m_rb2020b->Connect(wxEVT_RADIOBUTTON, wxCommandEventHandler(TopFrame::OnChangeTxMode), NULL, this);
 #endif // FREEDV_MODE_2020B
     
+    m_collpane->Connect(wxEVT_COLLAPSIBLEPANE_CHANGED, wxCollapsiblePaneEventHandler(TopFrame::OnChangeCollapseState), NULL, this);
+    
     m_sliderTxLevel->Connect(wxEVT_SCROLL_TOP, wxScrollEventHandler(TopFrame::OnChangeTxLevel), NULL, this);
     m_sliderTxLevel->Connect(wxEVT_SCROLL_BOTTOM, wxScrollEventHandler(TopFrame::OnChangeTxLevel), NULL, this);
     m_sliderTxLevel->Connect(wxEVT_SCROLL_LINEUP, wxScrollEventHandler(TopFrame::OnChangeTxLevel), NULL, this);
@@ -574,6 +605,8 @@ TopFrame::~TopFrame()
     this->Disconnect(wxEVT_SIZE, wxSizeEventHandler(TopFrame::topFrame_OnSize));
     this->Disconnect(wxEVT_UPDATE_UI, wxUpdateUIEventHandler(TopFrame::topFrame_OnUpdateUI));
     this->Disconnect(ID_EXIT, wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler(TopFrame::OnExit));
+    this->Disconnect(wxID_ANY, wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler(TopFrame::OnToolsEasySetup));
+    this->Disconnect(wxID_ANY, wxEVT_UPDATE_UI, wxUpdateUIEventHandler(TopFrame::OnToolsEasySetupUI));
     this->Disconnect(wxID_ANY, wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler(TopFrame::OnToolsAudio));
     this->Disconnect(wxID_ANY, wxEVT_UPDATE_UI, wxUpdateUIEventHandler(TopFrame::OnToolsAudioUI));
     this->Disconnect(wxID_ANY, wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler(TopFrame::OnToolsFilter));
@@ -620,6 +653,8 @@ TopFrame::~TopFrame()
     m_rb2020b->Disconnect(wxEVT_RADIOBUTTON, wxCommandEventHandler(TopFrame::OnChangeTxMode), NULL, this);
 #endif // FREEDV_MODE_2020B
     
+    m_collpane->Disconnect(wxEVT_COLLAPSIBLEPANE_CHANGED, wxCollapsiblePaneEventHandler(TopFrame::OnChangeCollapseState), NULL, this);
+    
     m_sliderTxLevel->Disconnect(wxEVT_SCROLL_TOP, wxScrollEventHandler(TopFrame::OnChangeTxLevel), NULL, this);
     m_sliderTxLevel->Disconnect(wxEVT_SCROLL_BOTTOM, wxScrollEventHandler(TopFrame::OnChangeTxLevel), NULL, this);
     m_sliderTxLevel->Disconnect(wxEVT_SCROLL_LINEUP, wxScrollEventHandler(TopFrame::OnChangeTxLevel), NULL, this);
@@ -632,3 +667,12 @@ TopFrame::~TopFrame()
     
     m_txtCtrlReportFrequency->Disconnect(wxEVT_TEXT, wxCommandEventHandler(TopFrame::OnChangeReportFrequency), NULL, this);
 }
+
+void TopFrame::OnChangeCollapseState(wxCollapsiblePaneEvent& event)
+{
+    auto bestSize = modeBox->GetBestSize();
+    auto curSize = modeBox->GetSize();
+
+    modeBox->SetSize(wxSize(curSize.GetWidth(), bestSize.GetHeight()));
+    rightSizer->Layout();
+}
